@@ -50,11 +50,11 @@ static void procview_clist_prepare (GTopProcViewData *);
 static void procview_clist_update (GTopProcViewData *);
 
 static const gchar *default_fonts [5] = {
-	"-*-courier-medium-r-*-*-8-*-*-*-m-*-*-*",
-	"-*-courier-medium-r-*-*-10-*-*-*-m-*-*-*",
-	"-*-courier-medium-r-*-*-12-*-*-*-m-*-*-*",
-	"-*-courier-medium-r-*-*-14-*-*-*-m-*-*-*",
-	"-*-courier-medium-r-*-*-18-*-*-*-m-*-*-*"
+	"-*-*-medium-r-*-*-8-*-*-*-*-*-*-*",
+	"-*-*-medium-r-*-*-10-*-*-*-*-*-*-*",
+	"-*-*-medium-r-*-*-12-*-*-*-*-*-*-*",
+	"-*-*-medium-r-*-*-14-*-*-*-*-*-*-*",
+	"-*-*-medium-r-*-*-18-*-*-*-*-*-*-*"
 };
 
 static GtkWidget *procview_properties_init (GnomePropertyObject *object);
@@ -145,10 +145,14 @@ CMP_STR (cmd);
 
 static GtkAdjustment *procfield_width_adjustments [GTOP_PROCFIELD_COUNT];
 
+#define DEFAULT_PROCVIEW_FIELD_MASK	20311
+
 gint default_field_width [GTOP_PROCFIELD_COUNT] = {
 	5, 8, 3, 3, 6, 6, 6, 6, 4, 5, 5, 7, 7, 7, 20
 };
 
+#define DEFAULT_MAX_CMD_WIDTH	20
+
 GTopProcField gtop_proc_fields [GTOP_PROCFIELD_COUNT] = {
 	{ N_("PID"), N_("Process ID"),
 	  PROCVIEW_PID, cmp_pid, SORT_ASC, 0, GTK_JUSTIFY_RIGHT, NULL},
@@ -203,11 +207,14 @@ static void procview_menu_cb_renice (GtkWidget *, GTopProcViewData *);
 
 static GList *widget_list = NULL;
 
+static gchar *get_command_line (pid_t, size_t);
+
 void
 procview_new (GTopProcViewData *d, GtkWidget *widget, gint ftype)
 {
 	GTopProcView *procview = GTOP_PROCVIEW (widget);
 	GtkStyle *style;
+	int i;
 		
 	d->bin = GTK_WIDGET (procview);
 	d->ftype = (GTopProcViewType) ftype;
@@ -217,11 +224,20 @@ procview_new (GTopProcViewData *d, GtkWidget *widget, gint ftype)
 
 	d->details.x = d->details.y = -1;
 
-	d->p_fields = g_new (GTopProcField, GTOP_PROCFIELD_COUNT);
+	d->p_fields = g_new0 (GTopProcField, GTOP_PROCFIELD_COUNT);
 
 	memcpy (d->p_fields, gtop_proc_fields,
 		sizeof (GTopProcField) * GTOP_PROCFIELD_COUNT);
 
+	d->cmd_field_index = -1;
+
+	for (i = 0; i < GTOP_PROCFIELD_COUNT; i++) {
+	    if (d->p_fields [i].fmt != PROCVIEW_CMD)
+		continue;
+
+	    d->cmd_field_index = i;
+	}
+
 	d->sort_field = -1;
 	d->sort_order = SORT_ASC;
 
@@ -266,7 +282,7 @@ procview_new (GTopProcViewData *d, GtkWidget *widget, gint ftype)
 		gtk_widget_show (d->summary_data->box);
 	}
 
-	gtk_box_pack_start (GTK_BOX (d->vbox), d->sw, TRUE, TRUE, GNOME_PAD);
+	gtk_box_pack_start (GTK_BOX (d->vbox), d->sw, TRUE, TRUE, 0);
 
 	gtk_container_add (GTK_CONTAINER (d->bin), d->vbox);
 
@@ -554,6 +570,8 @@ procview_renice (GTopProcViewData *d)
 	}
 }
 
+extern void gtop_show_mtbar (GtkWidget *w, gpointer gp);
+
 static GtkWidget *
 procview_clist_menu_prepare (GTopProcViewData *d)
 {
@@ -601,7 +619,7 @@ procview_clist_menu_prepare (GTopProcViewData *d)
 	gtk_menu_append (GTK_MENU (menu), mi);
 	gtk_widget_show (mi);
 
-	mi = gtk_menu_item_new_with_label (_("SIGTERM"));
+	mi = gtk_menu_item_new_with_label (_("Kill nicely (SIGTERM)"));
 	gtk_object_set_data
 		(GTK_OBJECT (mi), PROCVIEW_DATA_KEY, (gpointer) d);
 	gtk_signal_connect (GTK_OBJECT (mi), "activate",
@@ -610,7 +628,7 @@ procview_clist_menu_prepare (GTopProcViewData *d)
 	gtk_menu_append (GTK_MENU (menu), mi);
 	gtk_widget_show (mi);
 
-	mi = gtk_menu_item_new_with_label (_("SIGKILL"));
+	mi = gtk_menu_item_new_with_label (_("Kill now (SIGKILL)"));
 	gtk_object_set_data
 		(GTK_OBJECT (mi), PROCVIEW_DATA_KEY, (gpointer) d);
 	gtk_signal_connect (GTK_OBJECT (mi), "activate",
@@ -645,6 +663,25 @@ procview_clist_menu_prepare (GTopProcViewData *d)
 	gtk_menu_append (GTK_MENU (menu), mi);
 	gtk_widget_show (mi);
 
+	/* separator */
+	mi = gtk_menu_item_new ();
+	gtk_menu_append (GTK_MENU (menu), mi);
+	gtk_widget_show (mi);
+
+	mi = gtk_menu_item_new_with_label (_("Show menubar"));
+	gtk_signal_connect (GTK_OBJECT (mi), "activate",
+			    GTK_SIGNAL_FUNC (gtop_show_mtbar),
+			    (gpointer) FALSE);
+	gtk_menu_append (GTK_MENU (menu), mi);
+	gtk_widget_show (mi);
+
+	mi = gtk_menu_item_new_with_label (_("Show toolbar"));
+	gtk_signal_connect (GTK_OBJECT (mi), "activate",
+			    GTK_SIGNAL_FUNC (gtop_show_mtbar),
+			    (gpointer) TRUE);
+	gtk_menu_append (GTK_MENU (menu), mi);
+	gtk_widget_show (mi);
+
 	return menu;
 }
 
@@ -796,7 +833,7 @@ procview_init (GTopProcViewData *d)
 			d->field_list = g_list_append
 				(d->field_list, d->p_fields+i);
 
-			ip = g_new (gint, 1);
+			ip = g_new0 (gint, 1);
 			width = gtop_properties.procfields.field_width [i];
 
 			if (width < min_width)
@@ -961,6 +998,7 @@ procview_update (GTopProcViewData *d)
 	gint which, arg;
 	struct passwd *pwd;
 	int stime, utime;
+	size_t max_cmd_len;
 
 	unsigned long p_gl_main_mem;
 	ProcProcData *data;
@@ -1019,6 +1057,8 @@ procview_update (GTopProcViewData *d)
 	if (d->proc_selection_flags & (1 << GTOP_PROCVIEW_SYSTEM))
 		which |= GLIBTOP_EXCLUDE_SYSTEM;
 
+	memset (&proclist, 0, sizeof (glibtop_proclist));
+
 	d->proc_tab = glibtop_get_proclist (&proclist, which, arg);
 
 	if (d->proc_data) {
@@ -1036,13 +1076,17 @@ procview_update (GTopProcViewData *d)
 
 	n = proclist.number;
 
-	d->proc_data = (ProcProcData **) g_new (ProcProcData *, n+1);
+	d->proc_data = (ProcProcData **) g_new0 (ProcProcData *, n+1);
 	d->proc_data [n] = NULL;
 
+	max_cmd_len = (d->cmd_field_index >= 0) ?
+		gtop_properties.procfields.field_width [d->cmd_field_index] :
+			DEFAULT_MAX_CMD_WIDTH;
+
 	for (i = 0; i < n; i++) {
 		/* allocate proc_data */
 		data = d->proc_data [i] = 
-			(ProcProcData *) g_new (ProcProcData, 1);
+			(ProcProcData *) g_new0 (ProcProcData, 1);
 		data->d = d;
 
 		memset (&data->_p, 0, sizeof (data->_p));
@@ -1051,8 +1095,10 @@ procview_update (GTopProcViewData *d)
 		p->pid = d->proc_tab [i];
 
 		glibtop_get_proc_state (&procstate, p->pid);
-		
-		p->cmd = glibtop_strdup (procstate.cmd);
+
+		p->cmd = get_command_line (p->pid, max_cmd_len);
+		if (!p->cmd)
+		    p->cmd = glibtop_strdup (procstate.cmd);
 
 		p->state = procstate.state;
 
@@ -1153,6 +1199,67 @@ procview_update (GTopProcViewData *d)
 		procview_open_mem_maps (d);
 }
 
+#if LIBGTOP_VERSION_CODE >= 1001004
+
+static gchar *
+get_command_line (pid_t pid, size_t max_len)
+{
+	glibtop_array array;
+	char **args, *retval = NULL;
+    
+	args = glibtop_get_proc_args (&array, pid);
+
+	if (args && (array.number >= 1) && (array.size > 0)) {
+		size_t len;
+
+		len = strlen (args [0]);
+		if (len > max_len)
+			len = max_len;
+
+		if (len) {
+			retval = glibtop_malloc (len+1);
+			memcpy (retval, args [0], len);
+			*(retval+len) = 0;
+		}
+	}
+
+	if (args) {
+		int i;
+
+		for (i = 0; i < array.number; i++) {
+			glibtop_free (args [i]);
+		}
+
+		glibtop_free (args);
+	}
+
+	return retval;
+}
+
+#else /* LIBGTOP_VERSION_CODE < 1001004 */
+
+static gchar *
+get_command_line (pid_t pid, size_t max_len)
+{
+	glibtop_proc_args procargs;
+	gchar *args, *retval = NULL;
+
+	args = glibtop_get_proc_args (&procargs, pid, max_len);
+
+	if (args) {
+		if (strlen (args))
+			retval = glibtop_strdup (args);
+
+		glibtop_free (args);
+
+		return retval;
+	}
+
+	return NULL;
+}
+
+#endif /* LIBGTOP_VERSION_CODE < 1001004 */
+
 static void
 procview_properties_changed (GnomePropertyObject *object)
 {
@@ -1228,7 +1335,7 @@ procview_properties_init (GnomePropertyObject *object)
 	if (prop_ptr->details_flags & (1 << GTOP_DETAILS_AUTO_UPDATE))
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (label), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->button = label;
 	cb_data->object = object;
 	cb_data->index = GTOP_DETAILS_AUTO_UPDATE;
@@ -1245,7 +1352,7 @@ procview_properties_init (GnomePropertyObject *object)
 	if (prop_ptr->details_flags & (1 << GTOP_DETAILS_FULL_PATHNAMES))
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (label), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->button = label;
 	cb_data->object = object;
 	cb_data->index = GTOP_DETAILS_FULL_PATHNAMES;
@@ -1262,7 +1369,7 @@ procview_properties_init (GnomePropertyObject *object)
 	if (prop_ptr->details_flags & (1 << GTOP_DETAILS_REMEMBER_POSITION))
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (label), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->button = label;
 	cb_data->object = object;
 	cb_data->index = GTOP_DETAILS_REMEMBER_POSITION;
@@ -1288,7 +1395,7 @@ procview_properties_init (GnomePropertyObject *object)
 	if (prop_ptr->details_flags & (1 << GTOP_DETAILS_CUMULATIVE_TIMINGS))
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (label), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->button = label;
 	cb_data->object = object;
 
@@ -1329,13 +1436,13 @@ procview_properties_load (GnomePropertyObject *object)
 	sprintf (name, "gtop/procview/font_name=%s", default_font);
 	gtop_properties.procview.font_name = gnome_config_get_string (name);
 
-	gtop_properties.procview.font = gdk_font_load
+	gtop_properties.procview.font = gdk_fontset_load
 		(gtop_properties.procview.font_name);
 
 	if (!gtop_properties.procview.font) {
 		g_free (gtop_properties.procview.font_name);
 		gtop_properties.procview.font_name = g_strdup (default_font);
-		gtop_properties.procview.font = gdk_font_load
+		gtop_properties.procview.font = gdk_fontset_load
 			(gtop_properties.procview.font_name);
 	}
 
@@ -1429,7 +1536,7 @@ procfields_properties_init (GnomePropertyObject *object)
 			gtk_toggle_button_set_state
 				(GTK_TOGGLE_BUTTON (label), TRUE);
 
-		cb_data = g_new (RadioButtonCbData, 1);
+		cb_data = g_new0 (RadioButtonCbData, 1);
 
 		cb_data->index = i;
 		cb_data->button = label;
@@ -1481,11 +1588,19 @@ procfields_properties_apply (GnomePropertyObject *object)
 static void
 procfields_properties_load (GnomePropertyObject *object)
 {
-	gchar *string, *pos;
+	gchar *string, *pos, *default_string;
 	gint index = 0, i;
 
+	default_string = g_strdup_printf
+		("gtop/procview/procview_field_mask=%d",
+		 DEFAULT_PROCVIEW_FIELD_MASK);
+
 	gtop_properties.procfields.field_mask = gnome_config_get_int
-		("gtop/procview/procview_field_mask=20415");
+		(default_string);
+
+	if (!gtop_properties.procfields.field_mask)
+		gtop_properties.procfields.field_mask =
+			DEFAULT_PROCVIEW_FIELD_MASK;
 
 	for (i = 0; i < GTOP_PROCFIELD_COUNT; i++)
 		gtop_properties.procfields.field_width [i] =
